Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(389)

Unified Diff: cc/trees/proxy.h

Issue 2337913003: Fork cc::OutputSurface into cc::CompositorFrameSink. (Closed)
Patch Set: cfsfork: rebase Created 4 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: cc/trees/proxy.h
diff --git a/cc/trees/proxy.h b/cc/trees/proxy.h
index 54a3770fcb515352dbe01acb98a320bf587c6fb4..fd82d809b7259e89807cd192cce3e28ea045678c 100644
--- a/cc/trees/proxy.h
+++ b/cc/trees/proxy.h
@@ -27,7 +27,7 @@ namespace cc {
class BeginFrameSource;
class LayerTreeDebugState;
class LayerTreeMutator;
-class OutputSurface;
+class CompositorFrameSink;
// Abstract interface responsible for proxying commands from the main-thread
// side of the compositor over to the compositor implementation.
@@ -38,11 +38,12 @@ class CC_EXPORT Proxy {
virtual bool IsStarted() const = 0;
virtual bool CommitToActiveTree() const = 0;
// Will call LayerTreeHost::OnCreateAndInitializeOutputSurfaceAttempted
// with the result of this function.
- virtual void SetOutputSurface(OutputSurface* output_surface) = 0;
+ virtual void SetCompositorFrameSink(
+ CompositorFrameSink* compositor_frame_sink) = 0;
- virtual void ReleaseOutputSurface() = 0;
+ virtual void ReleaseCompositorFrameSink() = 0;
virtual void SetVisible(bool visible) = 0;

Powered by Google App Engine
@@ -38,11 +38,12 @@ class CC_EXPORT Proxy {
virtual bool IsStarted() const = 0;
virtual bool CommitToActiveTree() const = 0;
- // Will call LayerTreeHost::OnCreateAndInitializeOutputSurfaceAttempted
+ // Will call LayerTreeHost::OnCreateAndInitializeCompositorFrameSinkAttempted
// with the result of this function.
This is Rietveld 408576698